import React, {
  useState,
  useCallback,
  useEffect,
} from 'react';
import ReactDOM from 'react-dom';
import { csv, scaleBand, scaleLinear, max } from 'd3';

const csvUrl =
  'https://gist.githubusercontent.com/tomahawk-jupiter/b89c2b08a6b545cedec90c0b7b1d54ce/raw/c7eebbc7605957425eb30a7196443c002ed6e1b4/BattleTrafalgarLineShips.csv';

const width = 960;
const height = 500;
const margin = {
  top: 50,
  right: 50,
  bottom: 50,
  left: 150,
};

const App = () => {
	const [data, setData] = useState(null);

  useEffect(() => {
    const row = (d) => {
      d['No. of Decks'] = +d['No. of Decks'];
      d.Guns = +d.Guns;
      d['Complement'] = +d['Complement'];
      d['Killed'] = +d['Killed'];
      d['Wounded'] = +d['Wounded'];
      d['Total Casualties'] = +d['Total Casualties'];
      d['Casualties Percentage'] = +d['Casualties Percentage'].replace(/\D/g,'') / 100;
      return d;
    };
    csv(csvUrl, row).then(setData);
  }, []);
	
  if (!data) {
    return <pre>Loading...</pre>;
  }

  console.log(data[0]);

  const innerHeight = height - margin.top - margin.bottom;
  const innerWidth = width - margin.right - margin.left;

  const yScale = scaleBand()
    .domain(data.map((d) => d.Ship))
    .range([0, innerHeight]);

  const xScale = scaleLinear()
    .domain([0, max(data, (d) => d.Complement)])
    .range([0, innerWidth]);

  return (
    <svg width={width} height={height}>
      <g
        transform={`translate(${margin.left}, ${margin.top})`}
      >
        {xScale.ticks().map((tickValue) => (
          <g
            key={tickValue}
            transform={`translate(${xScale(tickValue)}, 0)`}
          >
            <line
              y2={innerHeight}
              stroke="black"
            />
            <text
              style={{ textAnchor: 'middle' }}
              dy=".71em"
              y={innerHeight + 3}
            >
              {tickValue}
            </text>
          </g>
        ))}
        {yScale.domain().map((tickValue) => (
          
          <text
            className='xAxisTickLabel'
            key={tickValue}
            style={{ textAnchor: 'end' }}
            x={-3}
            y={yScale(tickValue) + yScale.bandwidth() / 2}
            dy=".32em"
          >
            {tickValue}
          </text>
        ))}

        {data.map((d) => (
          <rect
            className='dataRect'
            key={d.Ship}
            x={0}
            y={yScale(d.Ship)}
            width={xScale(d.Complement)}
            height={yScale.bandwidth()}
          />
        ))}
      </g>
    </svg>
  );
};

const rootElement = document.getElementById('root');
ReactDOM.render(<App />, rootElement);
